@@ -248,36 +248,36 @@ c=======================================================================
 c+++++Data
       integer maxni,nrec,nsubject,nfixed,p,q,subject(nrec)
       integer datastr(nsubject,maxni+1),yr(nrec)
-      real*8 x(nrec,p),z(nrec,q),xtx(p,p)
+      double precision x(nrec,p),z(nrec,q),xtx(p,p)
 
 c+++++Prior 
       integer nu01,nu02,nu(2) 
-      real*8 aa0,ab0,a0b0(2) 
-      real*8 prec(p,p),sb(p)
-      real*8 tinv1(q,q)
-      real*8 smu(q),psiinv(q,q)
-      real*8 tinv2(q,q)
+      double precision aa0,ab0,a0b0(2) 
+      double precision prec(p,p),sb(p)
+      double precision tinv1(q,q)
+      double precision smu(q),psiinv(q,q)
+      double precision tinv2(q,q)
 
 c+++++MCMC parameters
       integer mcmc(3),nburn,nskip,nsave,ndisplay
 
 c+++++Current values of the parameters
       integer ncluster,ss(nsubject)
-      real*8 alpha
-      real*8 beta(p)
-      real*8 b(nsubject,q)
-      real*8 betar(q)
-      real*8 mu(nsubject,q)
-      real*8 sigma(q,q),sigmainv(q,q)
-      real*8 mub(q)
-      real*8 sigmab(q,q),sigmabinv(q,q)
+      double precision alpha
+      double precision beta(p)
+      double precision b(nsubject,q)
+      double precision betar(q)
+      double precision mu(nsubject,q)
+      double precision sigma(q,q),sigmainv(q,q)
+      double precision mub(q)
+      double precision sigmab(q,q),sigmabinv(q,q)
 
 c+++++Output
       integer clustsave(nsave,nsubject) 
-      real*8 cpo(nrec,2)
-      real*8 randsave(nsave,q*(nsubject+1))
-      real*8 musave(nsave,q*nsubject)
-      real*8 thetasave(nsave,q+nfixed+q+(q*(q+1))+2)
+      double precision cpo(nrec,2)
+      double precision randsave(nsave,q*(nsubject+1))
+      double precision musave(nsave,q*nsubject)
+      double precision thetasave(nsave,q+nfixed+q+(q*(q+1))+2)
 
 c+++++Seeds
       integer seed(2),seed1,seed2
@@ -288,30 +288,30 @@ c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 c+++++fixed effects
       integer iflagp(p)
-      real*8 workmhp(p*(p+1)/2),workmp(p,p),workvp(p)
-      real*8 xty(p)
+      double precision workmhp(p*(p+1)/2),workmp(p,p),workvp(p)
+      double precision xty(p)
 
 c+++++random effects
       integer iflagr(q)
-      real*8 theta(q)
-      real*8 workmhr(q*(q+1)/2),workmhr2(q*(q+1)/2)
-      real*8 workmr(q,q),workvr(q)
-      real*8 ztz(q,q),zty(q)
+      double precision theta(q)
+      double precision workmhr(q*(q+1)/2),workmhr2(q*(q+1)/2)
+      double precision workmr(q,q),workvr(q)
+      double precision ztz(q,q),zty(q)
 
 c+++++DPM
       integer cstrt(nsubject,nsubject)
       integer ccluster(nsubject)
-      real*8 prob(nsubject+1)
+      double precision prob(nsubject+1)
 
 c+++++Kernel
-      real*8 quadf(q,q)
+      double precision quadf(q,q)
 
 c+++++Latent data
-      real*8 y(nrec)
+      double precision y(nrec)
 
 c++++ model's performance
-      real*8 mc(5)
-      real*8 betasave(p),bsave(nsubject,q)
+      double precision mc(5)
+      double precision betasave(p),bsave(nsubject,q)
       
 c+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 c+++++Internal working space
@@ -321,25 +321,25 @@ c+++++General
       integer evali,ii,i,j,k,l,m,ni,ns 
       integer ok
       integer since,sprint 
-      real*8 sigma2e
-      real*8 tmp1,tmp2,tmp3
+      double precision sigma2e
+      double precision tmp1,tmp2,tmp3
       logical ainf,asup      
 
 c+++++MCMC
       integer dispcount,isave,iscan,nscan,skipcount 
 
 c+++++RNG and distributions
-      real*8 cdfnorm,dbin,rtnorm
+      double precision cdfnorm,dbin,rtnorm
 
 c+++++DP (functional parameter)
-      real*8 eps,rbeta,weight
+      double precision eps,rbeta,weight
       parameter(eps=0.01)
 
 c++++ model's performance
-      real*8 dbarc,dbar,dhat,pd,lpml
+      double precision dbarc,dbar,dhat,pd,lpml
 
 c+++++CPU time
-      real*8 sec00,sec0,sec1,sec
+      double precision sec00,sec0,sec1,sec
 
 c++++ parameters
       nburn=mcmc(1)
